package com.ll.dao;

import java.sql.*;
import java.util.ArrayList;
import java.util.List;

import com.ll.entity.User;
import com.ll.util.JDBCUtils;

public class UserDao {
	
	public boolean insertUser(User user){
		boolean flag = false;
		Connection conn = null;
		PreparedStatement ps = null;
		String sql = "insert into user (name,password,phone,address,age) values(?,?,?,?,?)";
		try {
			conn = JDBCUtils.getConnection();
			ps = conn.prepareStatement(sql);
			ps.setString(1, user.getName());
			ps.setString(2, user.getPassword());
			ps.setString(3, user.getPhone());
			ps.setString(4,user.getAddress());
			ps.setInt(5, user.getAge());
			int i = ps.executeUpdate();
			if(i==1){
				flag=true;
			}
		} catch (SQLException e) {
			e.printStackTrace();
			throw new RuntimeException("数据库异常");
		}finally{
			try {
				if(ps!=null){
					ps.close();
				}
				if(conn!=null){
					conn.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		return flag;
	}
	
	
	public User selectUserByName(String name){
		User user = null;
		Connection conn = null;
		PreparedStatement ps = null;
		ResultSet rs = null;
		String sql = "select * from user where name = ?";
		try {
			conn = JDBCUtils.getConnection();
			ps = conn.prepareStatement(sql);
			ps.setString(1, name);
			rs = ps.executeQuery();
			while(rs.next()){
				user = new User();
				user.setId(rs.getInt("id"));
				user.setName(name);
				user.setPassword(rs.getString("password"));
				user.setAddress(rs.getString("address"));
				user.setPhone(rs.getString("phone"));
				user.setAge(rs.getInt("age"));
				System.out.println(user.getId());
			}
		} catch (SQLException e) {
			e.printStackTrace();
			throw new RuntimeException("数据库异常");
		}finally{
			try {
				if(rs!=null){
					rs.close();
				}
				if(ps!=null){
					ps.close();
				}
				if(conn!=null){
					conn.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
			
		}
		return user;
	}
	
	public List<User> findAll() {
		List<User> list = new ArrayList<User>();
	    Connection conn = null;
	    Statement stmt = null;
	    ResultSet rs = null;
	    String sql = "select * from user";
	    try {
	    	conn = JDBCUtils.getConnection();
	    	stmt = conn.createStatement();
	      rs = stmt.executeQuery(sql);
	      while(rs.next()){
	        User user = new User();
	    	 int id = rs.getInt("id");
	        String password = rs.getString("password");
	        String name = rs.getString("name");
	        String phone = rs.getString("phone");
	        String address = rs.getString("address");
	        int age = rs.getInt("age");
	        user.setId(id);
	        user.setAddress(address);
	        user.setAge(age);
	        user.setName(name);
	        user.setPassword(password);
	        user.setPhone(phone);
	        list.add(user);
	      }
	    } catch (Exception e) {
	      e.printStackTrace();
	    } finally {
	      try {
	        rs.close();
	        stmt.close();
	        conn.close();
	      } catch (Exception e) {
	        e.printStackTrace();
	      }
	    }
	    return list;
	  }
	public static void main(String[] args) {
		UserDao userDao = new UserDao();
		User user =	userDao.selectUserByName("admin");
		System.out.println(user.getAddress());
		userDao.insertUser(user);
	}


	public boolean deleteUserById(int id) {
		boolean flag = false;
		Connection conn = null;
		PreparedStatement ps = null;
		String sql = "delete from user where id = ?";
		try {
			conn = JDBCUtils.getConnection();
			ps = conn.prepareStatement(sql);
			ps.setInt(1, id);
			int i = ps.executeUpdate();
			if(i==1){
				flag=true;
			}
		} catch (SQLException e) {
			e.printStackTrace();
			throw new RuntimeException("数据库异常");
		}finally{
			try {
				if(ps!=null){
					ps.close();
				}
				if(conn!=null){
					conn.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		return flag;
	}


	public boolean update(User user) {
		boolean flag = false;
		Connection conn = null;
		PreparedStatement ps = null;
		String sql = "update user set name = ?,password =?,phone = ?,address=?,age=? where id = ?";
		try {
			conn = JDBCUtils.getConnection();
			ps = conn.prepareStatement(sql);
			ps.setString(1, user.getName());
			ps.setString(2, user.getPassword());
			ps.setString(3, user.getPhone());
			ps.setString(4,user.getAddress());
			ps.setInt(5, user.getAge());
			ps.setInt(6, user.getId());
			int i = ps.executeUpdate();
			if(i==1){
				flag=true;
			}
		} catch (SQLException e) {
			e.printStackTrace();
			throw new RuntimeException("数据库异常");
		}finally{
			try {
				if(ps!=null){
					ps.close();
				}
				if(conn!=null){
					conn.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		return flag;
	}
}
